{% load wagtailadmin_tags i18n %}
<a href="{{action_url}}" class="wagtail-fedit-userbar-button button bicolor button--icon{% if hidden %} initially-hidden{% endif %}" name="action-publish" value="1">
    <span class="icon-wrapper">
        <svg xmlns="http://www.w3.org/2000/svg" fill="currentColor" class="w-action-icon" viewBox="0 0 16 16">
            <!-- The MIT License (MIT) -->
            <!-- Copyright (c) 2011-2024 The Bootstrap Authors -->
            <path d="M10.5 8a2.5 2.5 0 1 1-5 0 2.5 2.5 0 0 1 5 0"/>
            <path d="M0 8s3-5.5 8-5.5S16 8 16 8s-3 5.5-8 5.5S0 8 0 8m8 3.5a3.5 3.5 0 1 0 0-7 3.5 3.5 0 0 0 0 7"/>
        </svg>
    </span>
    {% translate "Publish" %}
</a>